package com.gic.qywx.self;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.http.entity.ContentType;
import org.apache.http.entity.mime.content.ByteArrayBody;
import org.apache.http.entity.mime.content.ContentBody;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

@RestController
@RequestMapping("/qywx")
public class QywxController {

    private static final Logger logger = LoggerFactory.getLogger(QywxController.class);

    @RequestMapping("self-post")
    public Object selfPost(String url, String json, String ip) {
        logger.info("自建post,url={},json={}", url, json);
        Map<String, Object> map = HttpClient.getWinxinResByJson(url, json, getIp(ip));
        return map;
    }

    @RequestMapping("self-post-json")
    public Object selfPostJson(String url, @RequestBody String json, String ip) {
        logger.info("自建post json,url={},json={}", url, json);
        Map<String, Object> map = HttpClient.getWinxinResByJson(url, json, getIp(ip));
        return map;
    }

    @RequestMapping("self-get")
    public Object selfGet(String url, String ip) {
        logger.info("自建get,url={}", url);
        Map<String, Object> map = HttpClient.getHttpByGet(url, getIp(ip));
        return map;
    }

    @RequestMapping("self-upload")
    public Object selfUpload(String url, String fileUrl, String fileName, String ip) {
        logger.info("自建upload,url={}", url);
        byte[] data = CommonUtil.getFileByte(fileUrl);
        Map<String, ContentBody> paramsMap = new HashMap<String, ContentBody>();
        paramsMap.put("media", new ByteArrayBody(data, ContentType.DEFAULT_BINARY, fileName));
        Map<String, Object> map = HttpClient.getWinxinResByFile(url, paramsMap, getIp(ip));
        return map;
    }

    @RequestMapping("self-upload-data")
    public Object selfImage(String url, String fileName, HttpServletRequest request, String ip) throws IOException {
        logger.info("自建upload-data,url={}", url);
        MultipartHttpServletRequest multiRequest = (MultipartHttpServletRequest) request;
        List<MultipartFile> list = multiRequest.getMultiFileMap().get("media");
        MultipartFile mf = list.get(0);
        byte[] data = mf.getBytes();
        Map<String, ContentBody> paramsMap = new HashMap<String, ContentBody>();
        paramsMap.put("media", new ByteArrayBody(data, ContentType.DEFAULT_BINARY, fileName));
        Map<String, Object> map = HttpClient.getWinxinResByFile(url, paramsMap, getIp(ip));
        return map;
    }
    
    // 必须是内网ip
    private byte[] getIp(String ip) {
        logger.info("ip={}",ip);
        if(StringUtils.isEmpty(ip)) {
            return null ;
        }
        String[] arr = ip.split("\\.");
        byte[] b = new byte[] {Integer.valueOf(arr[0]).byteValue(),  Integer.valueOf(arr[1]).byteValue(),Integer.valueOf(arr[2]).byteValue(),Integer.valueOf(arr[3]).byteValue()};
        return b;
    }
}
